@@ -15,3 +15,7 @@ class KwargsWarning(Warning):
 
 class PatternTypeWarning(Warning):
     """It warns if the spaczz pattern does not have a valid pattern type."""
+
+
+class MissingVectorsWarning(Warning):
+    """It warns if the spaCy Vocab does not have word vectors."""
