@@ -1,6 +1,5 @@
 """Module for fuzzy matching components."""
-from .fuzzyconfig import FuzzyConfig
 from .fuzzysearcher import FuzzySearcher
 
 
-__all__ = ["FuzzyConfig", "FuzzySearcher"]
+__all__ = ["FuzzySearcher"]
